==> vmp-0.4.2.tar.xz: vmp-0.4.2/framework/python/vmp/src/time_.cc <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 24/02/2020
 */

#include "vmp_.h"

struct stub_ctime_wrap:public pylib::Generic_def
{
    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
    {
         if(args.size() == 0)
             return pylib::Converter<vmp::str>(vmp::time::ctime_wrap());
         else if(args.size() == 1)
         {
             vmp_uint time=args.get<vmp_uint>(0);
             return pylib::Converter<vmp::str>(vmp::time::ctime_wrap(time));    
         }
         return 0;
    }
};

struct Localtime_stub_Constructor:public pylib::Constructor<vmp::time::Localtime>
{
    vmp::time::Localtime *build_instance(pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return new vmp::time::Localtime();
        else if(args.size() == 1)
        {
            vmp_uint time=args.get<vmp_uint>(0);
            return new vmp::time::Localtime(time);
            
        }
        return 0;
    }
};

void vmp_init_time(pylib::Module module)
{
    pylib::Module time=module.add_submodule("time");

    //vmp/time.h
    time.def_("vsleep",vmp::time::vsleep);
    time.def_("time_wrap",vmp::time::time_wrap);
    time.def_with_stub("ctime_wrap",stub_ctime_wrap());
    
    pylib::Class<vmp::time::Localtime> localtime=time.class_with_constructor<vmp::time::Localtime>("Localtime",Localtime_stub_Constructor());
    localtime.def_("sec",&vmp::time::Localtime::sec);
    localtime.def_("min",&vmp::time::Localtime::min);
    localtime.def_("hours",&vmp::time::Localtime::hours);
    localtime.def_("mday",&vmp::time::Localtime::mday);
    localtime.def_("wday",&vmp::time::Localtime::wday);
    localtime.def_("wday_n",&vmp::time::Localtime::wday_n);
    localtime.def_("month",&vmp::time::Localtime::month);
    localtime.def_("month_n",&vmp::time::Localtime::month_n);
    localtime.def_("year",&vmp::time::Localtime::year);
    
    pylib::Class<vmp::time::Timer> timer=time.class_<vmp::time::Timer>("Timer");
    timer.def_("init",&vmp::time::Timer::init);
    timer.def_("now",&vmp::time::Timer::now);
}

==> vmp-0.5.1.tar.xz: vmp-0.5.1/framework/python/vmp/src/time_.cc <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 10/07/2023
 */

#include "vmp_.h"

struct stub_ctime_wrap:public pylib::Generic_def
{
    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
    {
         if(args.size() == 0)
             return pylib::Converter<vmp::str>(vmp::time::ctime_wrap());
         else if(args.size() == 1)
         {
             vmp_uint time=args.get<vmp_uint>(0);
             return pylib::Converter<vmp::str>(vmp::time::ctime_wrap(time));    
         }
         return 0;
    }
};

struct stub_gmtime_wrap:public pylib::Generic_def
{
    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
    {
         if(args.size() == 0)
             return pylib::Converter<vmp::str>(vmp::time::gmtime_wrap());
         else if(args.size() == 1)
         {
             vmp_uint time=args.get<vmp_uint>(0);
             return pylib::Converter<vmp::str>(vmp::time::gmtime_wrap(time));    
         }
         return 0;
    }
};

struct Localtime_stub_Constructor:public pylib::Constructor<vmp::time::Localtime>
{
    vmp::time::Localtime *build_instance(pylib::Args &args,pylib::KwArgs &kwargs)
    {
        if(args.size() == 0)
            return new vmp::time::Localtime();
        else if(args.size() == 1)
        {
            vmp_uint time=args.get<vmp_uint>(0);
            return new vmp::time::Localtime(time);
            
        }
        return 0;
    }
};

void vmp_init_time(pylib::Module module)
{
    pylib::Module time=module.add_submodule("time");

    //vmp/time.h
    time.def_("vsleep",vmp::time::vsleep);
    time.def_("time_wrap",vmp::time::time_wrap);
    time.def_with_stub("ctime_wrap",stub_ctime_wrap());
    time.def_with_stub("gmtime_wrap",stub_gmtime_wrap());
    
    pylib::Class<vmp::time::Localtime> localtime=time.class_with_constructor<vmp::time::Localtime>("Localtime",Localtime_stub_Constructor());
    localtime.def_("sec",&vmp::time::Localtime::sec);
    localtime.def_("min",&vmp::time::Localtime::min);
    localtime.def_("hours",&vmp::time::Localtime::hours);
    localtime.def_("mday",&vmp::time::Localtime::mday);
    localtime.def_("wday",&vmp::time::Localtime::wday);
    localtime.def_("wday_n",&vmp::time::Localtime::wday_n);
    localtime.def_("month",&vmp::time::Localtime::month);
    localtime.def_("month_n",&vmp::time::Localtime::month_n);
    localtime.def_("year",&vmp::time::Localtime::year);
    
    pylib::Class<vmp::time::Timer> timer=time.class_<vmp::time::Timer>("Timer");
    timer.def_("init",&vmp::time::Timer::init);
    timer.def_("now",&vmp::time::Timer::now);
}
